
from configg.ini_backend import IniBackend
from configg.json_backend import JsonBackend
from configg.xml_backend import XmlBackend
from configg.configg import Configg
from configg.exceptions import *

INI_BACKEND = IniBackend
XML_BACKEND = XmlBackend
JSON_BACKEND = JsonBackend




