
import setuptools

setuptools.setup(name='configg',
      version='v0.4-alpha',
      description='Config data manager',
      author='Oliver',
      author_email='mail.ok65@googlemail.com',
      url='https://github.com/ok65/Configg',
      packages=['configg'],
     )
